@@ -102,7 +102,11 @@ class TerminalInteractiveShell(InteractiveShell):
     mime_renderers = Dict().tag(config=True)
 
     space_for_menu = Integer(6, help='Number of line at the bottom of the screen '
-                                     'to reserve for the completion menu'
+                                     'to reserve for the tab completion menu, '
+                                     'search history, ...etc, the height of '
+                                     'these menus will at most this value. '
+                                     'Increase it is you prefer long and skinny '
+                                     'menus, decrease for short and wide.'
                             ).tag(config=True)
 
     pt_app = None
@@ -164,9 +168,8 @@ class TerminalInteractiveShell(InteractiveShell):
 
     @observe('editing_mode')
     def _editing_mode(self, change):
-        u_mode = change.new.upper()
         if self.pt_app:
-            self.pt_app.editing_mode = u_mode
+            self.pt_app.editing_mode = getattr(EditingMode, change.new.upper())
 
     @observe('autoformatter')
     def _autoformatter_changed(self, change):
@@ -322,6 +325,7 @@ class TerminalInteractiveShell(InteractiveShell):
                             mouse_support=self.mouse_support,
                             enable_open_in_editor=self.extra_open_editor_shortcuts,
                             color_depth=self.color_depth,
+                            tempfile_suffix=".py",
                             **self._extra_prompt_options())
 
     def _make_style_from_name_or_cls(self, name_or_cls):
@@ -351,6 +355,7 @@ class TerminalInteractiveShell(InteractiveShell):
                     Token.Name.Function: '#2080D0',
                     Token.Name.Class: 'bold #2080D0',
                     Token.Name.Namespace: 'bold #2080D0',
+                    Token.Name.Variable.Magic: '#ansiblue',
                     Token.Prompt: '#009900',
                     Token.PromptNum: '#ansibrightgreen bold',
                     Token.OutPrompt: '#990000',
